$TITLE     PEP standard model 1-1
$STITLE    Single country static version, September 2009

* Authors: Bernard Decaluwe, Andre Lemelin, Helene Maisonnave
*          and Veronique Robichaud

* Acknoledgment:
* This file is part of a training material files developped by H.Maisonnave from
* the PEP team for the PEP and AGRODEP networks.
* An explanation on how to debug this file can be found in the document
* DEBUGATOR, How to debug a Computable General Equilibrium Model using GAMS.



* 1 Set definition

** 1.1 Sectors and commodities

SET

J All industries
/
 agr             Agriculture and other primary industries
 ind             Manufacturing and construction
 ser             Services
 adm             Public, administration
/

I All commodities
/
 agr             Agriculture and other primary commodities
 food            Food and beverages
 othind          Other manufacturing and construction
 ser             Services
 adm             Public administration
/

I1(I) All commodities except agriculture
/
 food            Food and beverages
 othind          Other manufacturing and construction
 ser             Services
 adm             Public administration
/

M(I) Imported goods
/
 agr             Agriculture and other primary commodities
 food            Food and beverages
 othind          Other manufacturing and construction
 ser             Services
/

NM(I) Non imported goods
/
 adm             Public administration
/

X(I) Exported goods

/
 agr             Agriculture and other primary commodities
 food            Food and beverages
 othind          Other manufacturing and construction
 ser             Services
/


NX(I) Non exported goods
/
 adm             Public administration
/


** 1.2 Production factors

L Labour categories
/
 l1              Unskilled workers
 l2              Skilled workers
/

K Capital categories
/
 cap             Capital
 land            Land
/


** 1.3 Agents

AG All agents
/
 hrp             Poor rural households
 hup             Poor urban households
 hrr             Rich rural households
 hur             Rich urban households
 firm            Firms
 gvt             Government
 row             Rest of the world
/

AGNG(AG) Non governemntal agents
/
 hrp             Poor rural households
 hup             Poor urban households
 hrr             Rich rural households
 hur             Rich urban households
 firm            Firms
 row             Rest of the world
/

AGD(AG) Domestic agents
/
 hrp             Poor rural households
 hup             Poor urban households
 hrr             Rich rural households
 hur             Rich urban households
 firm            Firms
 gvt             Government
/

H(AG) Households
/
 hrp             Poor rural households
 hup             Poor urban households
 hrr             Rich rural households
 hur             Rich urban households
/

F(AG) Firms
/
 firm            Firms
/
;

ALIAS (j,jj)
ALIAS (i,ij)
ALIAS (ag,agj)
ALIAS (h,hj)
ALIAS (l,lj)
ALIAS (k,kj)
;


* 2 Parameters and benchmark variables definition

** 2.1 Parameters

PARAMETERS
 aij(i,j)        Input output coefficient
 B_KD(j)         Scale parameter (CES - composite capital)
 B_LD(j)         Scale parameter (CES - composite labor)
 B_M(m)          Scale parameter (CES - composite commodity)
 B_VA(j)         Scale parameter (CES - value added)
 B_X(j,x)        Scale parameter (CET - exports and local sales)
 B_XT(j)         Scale parameter (CET - total output)
 beta_KD(k,j)    Share parameter (CES - composite capital)
 beta_LD(l,j)    Share parameter (CES - composite labor)
 beta_M(m)       Share parameter (CES - composite commodity)
 beta_VA(j)      Share parameter (CES - value added)
 beta_X(j,x)     Share parameter (CET - exports and local sales)
 beta_XT(j,i)    Share parameter (CET - total output)
 eta             Price elasticity of indexed transfers and parameters
 frisch(h)       Frisch parameter (LES function)
 gamma_GVT(i)    Share of commodity i in total current public expenditures on goods and services
 gamma_INV(i)    Share of commodity i in total investment expenditures
 gamma_LES(i,h)  Marginal share of commodity i in household h consumption budget
 io(j)           Coefficient (Leontief - intermediate consumption)
 kmob            Flag parameter (1 if capital is mobile)
 lambda_RK(ag,k) Share of type k capital income received by agent ag
 lambda_TR(ag,agj) Share parameter (transfer functions)
 lambda_WL(h,l)  Share of type l labor income received by type h households
 rho_KD(j)       Elasticity parameter (CES - composite capital)
 rho_LD(j)       Elasticity parameter (CES - composite labor)
 rho_M(m)        Elasticity parameter (CES - composite commodity)
 rho_VA(j)       Elasticity parameter (CES - value added)
 rho_X(j,x)      Elasticity parameter (CET - exports and local sales)
 rho_XT(j)       Elasticity parameter (CET - total output)
 sigma_KD(j)     Elasticity (CES - composite capital)
 sigma_LD(j)     Elasticity (CES - composite labor)
 sigma_M(m)      Elasticity (CES - composite commodity)
 sigma_VA(j)     Elasticity (CES - value added)
 sigma_X(j,x)    Elasticity (CET - exports and local sales)
 sigma_XT(j)     Elasticity (CET - total output)
 sigma_XD(x)     Price elasticity of the world demand for exports of product x
 sigma_Y(i,h)    Income elasticity of consumption
 sh0(h)          Intercept (type h household savings)
 sh1(h)          Slope (type h household savings)
 tmrg(i,ij)      Rate of margin i applied to commodity ij
 tmrg_X(i,x)     Rate of margin i applied to exported commodity x
 tr0(h)          Intercept (transfers by type h households to government)
 tr1(h)          Marginal rate of transfers by type h households to government
 ttdf0(f)        Intercept (income taxes of type f businesses)
 ttdf1(f)        Marginal income tax rate of type f businesses
 ttdh0(h)        Intercept (income taxes of type h households)
 ttdh1(h)        Marginal income tax rate of type h households
 ttic(i)         Tax rate on commodity i
 ttik(k,j)       Tax rate on type k capital used in industry j
 ttim(m)         Rate of taxes and duties on imports of commodity m
 ttip(j)         Tax rate on the production of industry j
 ttiw(l,j)       Tax rate on type l worker compensation in industry j
 ttix(x)         Export tax rate on exported commodity x
 v(j)            Coefficient (Leontief - value added)


** 2.2 Variables - Benchmark
* Benchmark values of variables are parameters.
* Their acronyms are the corresponding variable names,
* followed by the letter "O".

**  2.2.1 Volume variables
 CO(i,h)         Consumption of commodity i by type h households
 CGO(i)          Public consumption of commodity i
 CIO(j)          Total intermediate consumption of industry j
 CMINO(i,h)      Minimum consumption of commodity i by type h households
 DDO(i)          Domestic demand for commodity i produced locally
 DIO(i,j)        Intermediate consumption of commodity i by industry j
 DITO(i)         Total intermediate demand for commodity i
 DSO(j,i)        Supply of commodity i by sector j to the domestic market
 EXO(j,x)        Quantity of product x exported by sector j
 EXDO(x)         World demand for exports of product x
 IMO(m)          Quantity of product m imported
 INVO(i)         Final demand of commodity i for investment purposes (GFCF)
 KDO(k,j)        Demand for type k capital by industry j
 KDCO(j)         Industry j demand for composite capital
 KSO(k)          Supply of type k capital
 LDO(l,j)        Demand for type l labor by industry j
 LDCO(j)         Industry j demand for composite labor
 LSO(l)          Supply of type l labor
 MRGNO(i)        Demand for commodity i as a trade or transport margin
 QO(i)           Quantity demanded of composite commodity i
 VAO(j)          Value added of industry j
 VSTKO(i)        Inventory change of commodity i
 XSO(j,i)        Industry j production of commodity i
 XSTO(j)         Total aggregate output of industry j

**  2.2.2 Price variables
 eO              Exchange rate (price of foreign currency in local currency)
 PO(j,i)         Basic price of industry j's production of commodity i
 PCO(i)          Purchaser price of composite comodity i (including all taxes and margins)
 PCIO(j)         Intermediate consumption price index of industry j
 PDO(i)          Price of local product i sold on the domestic market (including all taxes and margins)
 PEO(x)          Price received for exported commodity x (excluding export taxes)
 PE_FOBO(x)      FOB price of exported commodity x (in local currency)
 PIXCONO         Consumer price index
 PIXGDPO         GDP deflator
 PIXGVTO         Public expenditures price index
 PIXINVO         Investment price index
 PLO(i)          Price of local product i (excluding all taxes on products)
 PMO(m)          Price of imported product m (including all taxes and tariffs)
 PPO(j)          Industry j unit cost including taxes directly related to the use of capital and labor but excluding other taxes on production
 PTO(j)          Basic price of industry j's output
 PVAO(j)         Price of industry j value added (including taxes on production directly related to the use of capital and labour)
 PWMO(m)         World price of imported product m (expressed in foreign currency)
 PWXO(x)         World price of exported product x (expressed in foreign currency)
 RO(k,j)         Rental rate of type k capital in industry j
 RCO(j)          Rental rate of industry j composite capital
 RKO(k)          Rental rate of type k capital (if capital is mobile)
 RTIO(k,j)       Rental rate paid by industry j for type k capital including capital taxes
 WO(l)           Wage rate of type l labor
 WCO(j)          Wage rate of industry j composite labor
 WTIO(l,j)       Wage rate paid by industry j for type l labor including payroll taxes

**  2.2.3 Nominal (value) variables
 CABO            Current account balance
 CTHO(h)         Consumption budget of type h households
 GO              Current government expenditures on goods and services
 GDP_BPO         GDP at basic prices
 GDP_FDO         GDP at purchasers' prices from the perspective of final demand
 GDP_IBO         GDP at market prices (income-based)
 GDP_MPO         GDP at market prices
 GFCFO           Gross fixed capital formation
 ITO             Total investment expenditures
 SFO(f)          Savings of type f businesses
 SGO             Government savings
 SHO(h)          Savings of type h households
 SROWO           Rest-of-the-world savings
 TDFO(f)         Income taxes of type f businesses
 TDFTO           Total government revenue from business income taxes
 TDHO(h)         Income taxes of type h households
 TDHTO           Total government revenue from household income taxes
 TICO(i)         Government revenue from indirect taxes on product i
 TICTO           Total government receipts of indirect taxes on commodities
 TIKO(k,j)       Government revenue from taxes on type k capital used by industry j
 TIKTO           Total government revenue from from taxes on capital
 TIMO(m)         Government revenue from import duties on product m
 TIMTO           Total government revenue from import duties
 TIPO(j)         Government revenue from taxes on industry j production (excluding taxes directly related to the use of capital and labor)
 TIPTO           Total government revenue from production taxes (excluding taxes directly related to the use of capital and labor)
 TIWO(l,j)       Government revenue from payroll taxes on type l labor in industry j
 TIWTO           Total government revenue from payroll taxes
 TIXO(x)         Government revenue from export taxes on product x
 TIXTO           Total government revenue from export taxes
 TPRCTSO         Total government revenue from taxes on products and imports
 TPRODNO         Total government revenue from other taxes on production
 TRO(ag,agj)     Transfers from agent agj to agent ag
 YDFO(f)         Disposable income of type f businesses
 YDHO(h)         Disposable income of type h households
 YFO(f)          Total income of type f businesses
 YFKO(f)         Capital income of type f businesses
 YFTRO(f)        Transfer income of type f businesses
 YGO             Total government income
 YGKO            Government capital income
 YGTRO           Government transfer income
 YHO(h)          Total income of type h households
 YHKO(h)         Capital income of type h households
 YHLO(h)         Labor income of type h households
 YHTRO(h)        Transfer income of type h households
 YROWO           Rest-of-the-world income
;

* 3 Data

** 3.1 Data from the SAM
*  SAM data are nominal values. However, several volume variables are
*  provisionally set equal to the corresponding nominal SAM value. Once the
*  benchmark prices have been set or calibrated, volumes will be re-calculated
*  (section 4.4).

PARAMETER
SAM(*,*,*,*);

$CALL GDXXRW.EXE SAM-V1_1.xls par=SAM rng=SAM!A4:AJ39 Rdim=2 Cdim=2
$GDXIN SAM-V1_1.gdx
$LOAD SAM
$GDXIN

 CO(i,h)         = SAM('I',i,'AG',h);
 CGO(i)          = SAM('I',i,'AG','gvt');
 DSO(j,i)        = SAM('J',j,'I',i);
 DDO(i)          = SUM[j,DSO(j,i)];
 DIO(i,j)        = SAM('I',i,'J',j);
 EXO(j,x)        = SAM('J',j,'X',x);
 EXDO(x)         = SAM('X',x,'AG','ROW');
 INVO(i)         = SAM('I',i,'OTH','INV');
 VSTKO(i)        = SAM('I',i,'OTH','VSTK');
 IMO(m)          = SAM('AG','ROW','I',m);
 KDO(k,j)        = SAM('K',k,'J',j);
 LDO(l,j)        = SAM('L',l,'J',j);
 SFO(f)          = SAM('OTH','INV','AG',f);
 SGO             = SAM('OTH','INV','AG','GVT');
 SHO(h)          = SAM('OTH','INV','AG',h);
 SROWO           = SAM('OTH','INV','AG','ROW');
 TDFO(f)         = SAM('AG','TD','AG',f);
 TDHO(h)         = SAM('AG','TD','AG',h);
 TICO(i)         = SAM('AG','TI','I',i);
 TIKO(k,j)       = SAM('AG',k,'J',j);
 TIMO(m)         = SAM('AG','TM','I',m);
 TIPO(j)         = SAM('AG','GVT','J',j);
 TIXO(x)         = SAM('AG','GVT','X',x);
 TIWO(l,j)       = SAM('AG',l,'J',j);
 TRO(ag,agj)     = SAM('AG',ag,'AG',agj);
 lambda_RK(ag,k) = SAM('AG',ag,'K',k);
 lambda_WL(h,l)  = SAM('AG',h,'L',l);
 tmrg(i,ij)      = SAM('I',i,'I',ij);
 tmrg_X(i,x)     = SAM('I',i,'X',x);


** 3.2 Other data
** Some parameters cannot be calibrated using SAM values

** Price elasticity (should be set equal to one when verifying model homogeneity)
 eta             = 1;

** CES and CET elasticities
 sigma_KD(j)     = 0.8;
 sigma_LD(j)     = 0.8;
 sigma_M(m)      = 2;
 sigma_VA(j)     = 1.5;
 sigma_X(j,x)    = 2;
 sigma_XT(j)     = 2;

** Elasticity of international demand for exported commodity x
 sigma_XD(x)     = 2;

** LES parameters
 frisch(h)       = -1.5;
 sigma_y('agr',h)= 0.7;
 sigma_y('food',h)
                 = 1.1;
 sigma_y('othind',h)
                 = 1.1;
 sigma_y('ser',h)= 1.05;
 sigma_y('adm',h)= 1.05;

** Intercepts of transfers, direct taxes and savings
*  One can either choose to assign a value to the intercept and calibrate
*  the slopes accordingly, or the other way around. This type of modelling
*  can be useful to take into account known marginal savings or taxation rates
*  or to deal with negative average saving rates in cases where savings are
*  negative for some household groups.
*  When no further information is available, one can simply set the intercepts
*  to zero and calibrate an average rate: this is what we do here.
 sh0(h)          = 0;
 tr0(h)          = 0;
 ttdf0(f)        = 0;
 ttdh0(h)        = 0;

** Also we need to assign values to some prices
 eO              = 1;
 PEO(x)          = 1;
 PLO(i)          = 1;
 PWMO(m)         = 1;
 WO(l)           = 1;
 RKO(k)          = 1;
 RO(k,j)         = RKO(k);

* 4 Calibration

** 4.1 Calculation of income and savings related variables and parameters

 YHKO(h)         = SUM[k,lambda_RK(h,k)];
 YHLO(h)         = SUM[l,lambda_WL(h,l)];
 YHTRO(h)        = SUM[ag,TRO(h,ag)];
 YHO(h)          = YHLO(h)+YHKO(h)+YHTRO(h);
 YDHO(h)         = YHO(h)-TDHO(h)-TRO('gvt',h);
 CTHO(h)         = YDHO(h)-SHO(h)-SUM[agng,TRO(agng,h)];

 YFKO(f)         = SUM[k,lambda_RK(f,k)];
 YFTRO(f)        = SUM[ag,TRO(f,ag)];
 YFO(f)          = YFKO(f)+YFTRO(f);
 YDFO(f)         = YFO(f)-TDFO(f);

 YGKO            = SUM[k,lambda_RK('gvt',k)];
 TDHTO           = SUM[h,TDHO(h)];
 TDFTO           = SUM[f,TDFO(f)];
 TICTO           = SUM[i,TICO(i)];
 TIMTO           = SUM[m,TIMO(m)];
 TIXTO           = SUM[x,TIXO(x)];
 TIWTO           = SUM[(l,j),TIWO(l,j)];
 TIKTO           = SUM[(k,j),TIKO(k,j)];
 TIPTO           = SUM[j,TIPO(j)];
 TPRODNO         = TIKTO+TIWTO+TIPTO;
 TPRCTSO         = TICTO+TIMTO+TIXTO;
 YGTRO           = SUM[ag,TRO('gvt',ag)];
 YGO             = YGKO+TDHTO+TDFTO+TPRODNO+TPRCTSO+YGTRO;

 YROWO           = SUM[m,IMO(m)]+SUM[k,lambda_RK('row',k)]
                  +SUM[ag,TRO('row',ag)];
 CABO            = -SROWO;

 ITO             = SUM[h,SHO(h)]+SUM[f,SFO(f)]+SGO+SROWO;

 lambda_RK(ag,k) = lambda_RK(ag,k)/SUM[j,KDO(k,j)];
 lambda_WL(h,l)  = lambda_WL(h,l)/SUM[j,LDO(l,j)];
 lambda_TR(agng,h)
                 = TRO(agng,h)/YDHO(h);
 lambda_TR(ag,f) = TRO(ag,f)/YDFO(f);

 sh1(h)          = [SHO(h)-sh0(h)]/YDHO(h);
 tr1(h)          = [TRO('gvt',h)-tr0(h)]/YHO(h);

** 4.2 Calibration of investment and government spending shares

 gamma_GVT(i)    = CGO(i)/SUM[ij,CGO(ij)];
 gamma_INV(i)    = INVO(i)/SUM[ij,INVO(ij)];


** 4.3 Calibration of direct tax rates

 ttdf1(f)        = [TDFO(f)-ttdf0(f)]/YFKO(f);
 ttdh1(h)        = [TDHO(h)-ttdh0(h)]/YHO(h);

** 4.4 Calibration of other tax rates, prices, margins and volumes

 PCO(m)          = [DDO(m)+IMO(m)+SUM(ij,tmrg(ij,m))+TICO(m)+TIMO(m)]
                  /[DDO(m)+IMO(m)];
 PCO(nm)         = [DDO(nm)+SUM(ij, tmrg(ij,nm))+TICO(nm)]
                  /[DDO(nm)];
 tmrg(i,ij)      = tmrg(i,ij)/PCO(i);
 tmrg_X(i,x)     = tmrg_X(i,x)/PCO(i);

 DDO(i)          = DDO(i)/PLO(i);
 IMO(m)          = IMO(m)/(PWMO(m)*eO);

 tmrg(i,nm)      = tmrg(i,nm)/DDO(nm);
 tmrg(i,m)       = tmrg(i,m)/{DDO(m)+IMO(m)};

 ttic(nm)        = TICO(nm)/{(PLO(nm)+SUM[i,PCO(i)*tmrg(i,nm)])*DDO(nm)};
 ttic(m)         = TICO(m)/{(PLO(m)+SUM[i,PCO(i)*tmrg(i,m)])*DDO(m)
                           +(eO*PWMO(m)+SUM[i,PCO(i)*tmrg(i,m)])*IMO(m)
                           +TIMO(m)};

 PDO(i)          = {PLO(i)+SUM[ij,PCO(ij)*tmrg(ij,i)]}*(1+ttic(i));

 ttim(m)         = TIMO(m)/[eO*PWMO(m)*IMO(m)];

 PMO(m)          = {(1+ttim(m))*eO*PWMO(m)+SUM[i,PCO(i)*tmrg(i,m)]}*(1+ttic(m));

 EXO(j,x)        = EXO(j,x)/PEO(x);
 tmrg_X(i,x)     = tmrg_X(i,x)/SUM[j,EXO(j,x)];
 ttix(x)         = TIXO(x)/[EXDO(x)-TIXO(x)];
 PE_FOBO(x)      = (1+ttix(x))*(PEO(x)+SUM[i,PCO(i)*tmrg_X(i,x)]);
 PWXO(x)         = PE_FOBO(x)/eO;
 EXDO(x)         = EXDO(x)/(PWXO(x)*eO);

 XSO(j,nx)       = DSO(j,nx);
 PO(j,nx)        = PLO(nx);

 DSO(j,i)        = DSO(j,i)/PLO(i);
 XSO(j,x)        = DSO(j,x)+EXO(j,x);
 PO(j,x)$XSO(j,x)= [PLO(x)*DSO(j,x)+PEO(x)*EXO(j,x)]/XSO(j,x);
 XSTO(j)         = SUM[i,XSO(j,i)];


 PTO(j)          = SUM[i$XSO(j,i),PO(j,i)*XSO(j,i)]/XSTO(j);

 QO(nm)          = DDO(nm);
 QO(m)           = IMO(m)+DDO(m);

 MRGNO(i)        = SUM[ij,tmrg(i,ij)*DDO(ij)]+
                   SUM[m,tmrg(i,m)*IMO(m)]+
                   SUM[(j,x),tmrg_X(i,x)*EXO(j,x)];

 CO(i,h)         = CO(i,h)/PCO(i);
 CGO(i)          = CGO(i)/PCO(i);
 DIO(i,j)        = DIO(i,j)/PCO(i);
 INVO(i)         = INVO(i)/PCO(i);
 VSTKO(i)        = VSTKO(i)/PCO(i);
 GFCFO           = ITO-SUM[i,PCO(i)*VSTKO(i)];

 CIO(j)          = SUM[i,DIO(i,j)];
 DITO(i)         = SUM[j,DIO(i,j)];
 GO              = SUM[i,PCO(i)*CGO(i)];

 PCIO(j)         = SUM[i,PCO(i)*DIO(i,j)]/CIO(j);

 ttiw(l,j)$LDO(l,j)
                 = TIWO(l,j)/LDO(l,j);
 WTIO(l,j)       = WO(l)*(1+ttiw(l,j));
 ttik(k,j)$KDO(k,j)
                 = TIKO(k,j)/KDO(k,j);
 RTIO(k,j)       = RO(k,j)*(1+ttik(k,j));

 LDO(l,j)        = LDO(l,j)/WO(l);
 LDCO(j)         = SUM[l,LDO(l,j)];
 LSO(l)          = SUM[j,LDO(l,j)];
 WCO(j)$LDCO(j)  = SUM[l,WTIO(l,j)*LDO(l,j)]/LDCO(j);

 KDO(k,j)        = KDO(k,j)/RO(k,j);
 KDCO(j)         = SUM[k,KDO(k,j)];
 KSO(k)          = SUM[j,KDO(k,j)];
 RCO(j)$KDCO(j)  = SUM[k,RTIO(k,j)*KDO(k,j)]/KDCO(j);

 VAO(j)          = LDCO(j)+KDCO(j);
 PVAO(j)         = [WCO(j)*LDCO(j)+RCO(j)*KDCO(j)]/VAO(j);

 ttip(j)         = TIPO(j)/{PVAO(j)*VAO(j)+SUM[i,PCO(i)*DIO(i,j)]};

 PPO(j)          = PTO(j)/(1+ttip(j));

 PIXGDPO         = {SUM[j,PVAO(j)*VAO(j)]/SUM[j,PVAO(j)*VAO(j)]*
                    SUM[j,PVAO(j)*VAO(j)]/SUM[j,PVAO(j)*VAO(j)]}**0.5;

 PIXCONO         = SUM[i,PCO(i)*SUM[h,CO(i,h)]]/SUM[i,PCO(i)*SUM[h,CO(i,h)]];

 PIXGVTO         = PROD[i$gamma_GVT(i),(PCO(i)/PCO(i))**gamma_GVT(i)];

 PIXINVO         = PROD[i$gamma_INV(i),(PCO(i)/PCO(i))**gamma_INV(i)];


** 4.5 Calibration of indexed transfers and parameters

 TRO(agd,'row')  = TRO(agd,'row')/PIXCONO**eta;
 TRO(agng,'gvt') = TRO(agng,'gvt')/PIXCONO**eta;
 ttdf0(f)        = ttdf0(f)/PIXCONO**eta;
 ttdh0(h)        = ttdh0(h)/PIXCONO**eta;
 sh0(h)          = sh0(h)/PIXCONO**eta;
 tr0(h)          = tr0(h)/PIXCONO**eta;


** 4.6 Calibration of function parameters

**  4.6.1 Leontief functions
 io(j)           = CIO(j)/XSTO(j);
 v(j)            = VAO(j)/XSTO(j);
 aij(i,j)        = DIO(i,j)/CIO(j);

**  4.6.2 Calibration of CET parameters
**   4.6.2.1 CET between commodities
 rho_XT(j)       = (1+sigma_XT(j))/sigma_XT(j);
 beta_XT(j,i)${XSO(j,i) and (SUM[ij,XSO(j,ij)] gt 0)}
                 = PO(j,i)*XSO(j,i)**(1-rho_XT(j))/
                   SUM[ij$XSO(j,ij),PO(j,ij)*XSO(j,ij)**(1-rho_XT(j))];
 B_XT(j)         = XSTO(j)
                  /SUM[i$XSO(j,i),beta_XT(j,i)*XSO(j,i)**rho_XT(j)
                  ]**(1/rho_XT(j));

**   4.6.2.2 CET between exports and local production
 rho_X(j,x)      = (1+sigma_X(j,x))/sigma_X(j,x);
 beta_X(j,x)$(EXO(j,x) and DSO(j,x))
                 = PEO(x)*EXO(j,x)**(1-rho_X(j,x))/
                  [PEO(x)*EXO(j,x)**(1-rho_X(j,x))
                  +PLO(x)*DSO(j,x)**(1-rho_X(j,x))];
 B_X(j,x)$(EXO(j,x) and DSO(j,x))
                 = XSO(j,x)/
                 [beta_X(j,x)*EXO(j,x)**rho_X(j,x)+
                 (1-beta_X(j,x))*DSO(j,x)**rho_X(j,x)]
                 **(1/rho_X(j,x));

**  4.6.3 Calibration of CES parameters
**   4.6.3.1 Composite good
 rho_M(m)        = (1-sigma_M(m))/sigma_M(m);
 beta_M(m)       = PMO(m)*IMO(m)**(rho_M(m)+1)/
                   [PMO(m)*IMO(m)**(rho_M(m)+1)+
                    PDO(m)*DDO(m)**(rho_M(m)+1)];
 B_M(m)          = QO(m)
                   /[beta_M(m)*IMO(m)**(-rho_M(m))+
                   (1-beta_M(m))*DDO(m)**(-rho_M(m))
                   ]**(-1/rho_M(m));

**   4.6.3.2 Composite capital
 rho_KD(j)       = (1-sigma_KD(j))/sigma_KD(j);
 beta_KD(k,j)$KDO(k,j)
                 = RTIO(k,j)*KDO(k,j)**(rho_KD(j)+1)/
                   SUM[kj,RTIO(kj,j)*KDO(kj,j)**(rho_KD(j)+1)];
 B_KD(j)$KDCO(j) = KDCO(j)
                  /SUM[k$KDO(k,j),beta_KD(k,j)*KDO(k,j)**(-rho_KD(j))
                  ]**(-1/rho_KD(j));

**   4.6.3.3 Composite labour
 rho_LD(j)       = (1-sigma_LD(j))/sigma_LD(j);
 beta_LD(l,j)$LDO(l,j)
                 = WTIO(l,j)*LDO(l,j)**(rho_LD(j)+1)/
                   SUM[lj,WTIO(lj,j)*LDO(lj,j)**(rho_LD(j)+1)];
 B_LD(j)         = LDCO(j)/SUM[l,beta_LD(l,j)$LDO(l,j)*LDO(l,j)**(-rho_LD(j))]
                            **(-1/rho_LD(j));

**   4.6.3.4 Value added
 rho_VA(j)       = (1-sigma_VA(j))/sigma_VA(j);
 beta_VA(j)$KDCO(j)
                 = WCO(j)*LDCO(j)**(rho_VA(j)+1)/
                  [WCO(j)*LDCO(j)**(rho_VA(j)+1)+
                   RCO(j)*KDCO(j)**(rho_VA(j)+1)];
 B_VA(j)$KDCO(j)
                 = VAO(j)
                   /[beta_VA(j)*LDCO(j)**(-rho_VA(j))+
                   (1-beta_VA(j))*KDCO(j)**(-rho_VA(j))
                   ]**(-1/rho_VA(j));

**  4.6.4 Calibration of LES parameters
*   As the assigned values of income elasticities may not result in
*   consumption shares that add up to 1, this first step
*   adjusts the elasticities proportionnaly

 sigma_Y(i,h)    = sigma_Y(i,h)/{SUM[ij,sigma_Y(ij,h)*PCO(ij)*CO(ij,h)]
                  /CTHO(h)};
 gamma_LES(i,h)  = PCO(i)*CO(i,h)*sigma_Y(i,h)/CTHO(h);
 CMINO(i,h)      = CO(i,h)+gamma_LES(i,h)*[CTHO(h)/
                  (PCO(i)*frisch(h))];

** 4.7 Calibration of gross domestic products

 GDP_BPO         = SUM[j,PVAO(j)*VAO(j)]+TIPTO;
 GDP_MPO         = GDP_BPO+TPRCTSO;
 GDP_IBO         = SUM[(l,j),WO(l)*LDO(l,j)]+SUM[(k,j),RO(k,j)*KDO(k,j)]
                   +TPRODNO+TPRCTSO;
 GDP_FDO         = SUM{i,PCO(i)*(SUM[h,CO(i,h)]+CGO(i)+INVO(i)+VSTKO(i))}
                  +SUM[x,PE_FOBO(x)*EXDO(x)]-SUM[m,PWMO(m)*eO*IMO(m)];


* 5 Model

** 5.1 Variable definition

VARIABLES

**  5.1.1 Volume variables
 C(i,h)          Consumption of commodity i by type h households
 CG(i)           Public final consumption of commodity i
 CI(j)           Total intermediate consumption of industry j
 CMIN(i,h)       Minimum consumption of commodity i by type h households
 DD(i)           Domestic demand for commodity i produced locally
 DI(i,j)         Intermediate consumption of commodity i by industry j
 DIT(i)          Total intermediate demand for commodity i
 DS(j,i)         Supply of commodity i by sector j to the domestic market
 EX(j,x)         Quantity of product x exported by sector j
 EXD(x)          World demand for exports of product x
 IM(m)           Quantity of product m imported
 INV(i)          Final demand of commodity i for investment purposes (GFCF)
 KD(k,j)         Demand for type k capital by industry j
 KDC(j)          Industry j demand for composite capital
 KS(k)           Supply of type k capital
 LD(l,j)         Demand for type l labor by industry j
 LDC(j)          Industry j demand for composite labor
 LS(l)           Supply of type l labor
 MRGN(i)         Demand for commodity i as a trade or transport margin
 Q(i)            Quantity demanded of composite commodity i
 VA(j)           Value added of industry j
 VSTK(i)         Inventory change of commodity i
 XS(j,i)         Industry j production of commodity i
 XST(j)          Total aggregate output of industry j

**  5.1.2 Price variables
 e               Exchange rate (price of foreign currency in local currency)
 P(j,i)          Basic price of industry j's production of commodity i
 PC(i)           Purchaser price of composite comodity i (including all taxes and margins)
 PCI(j)          Intermediate consumption price index of industry j
 PD(i)           Price of local product i sold on the domestic market (including all taxes and margins)
 PE(x)           Price received for exported commodity x (excluding export taxes)
 PE_FOB(x)       FOB price of exported commodity x (in local currency)
 PIXCON          Consumer price index
 PIXGDP          GDP deflator
 PIXGVT          Public expenditures price index
 PIXINV          Investment price index
 PL(i)           Price of local product i (excluding all taxes on products)
 PM(m)           Price of imported product m (including all taxes and tariffs)
 PP(j)           Industry j unit cost including taxes directly related to the use of capital and labor but excluding other taxes on production
 PT(j)           Basic price of industry j's output
 PVA(j)          Price of industry j value added (including taxes on production directly related to the use of capital and labour)
 PWM(m)          World price of imported product m (expressed in foreign currency)
 PWX(x)          World price of exported product x (expressed in foreign currency)
 R(k,j)          Rental rate of type k capital in industry j
 RC(j)           Rental rate of industry j composite capital
 RK(k)           Rental rate of type k capital (if capital is mobile)
 RTI(k,j)        Rental rate paid by industry j for type k capital including capital taxes
 W(l)            Wage rate of type l labor
 WC(j)           Wage rate of industry j composite labor
 WTI(l,j)        Wage rate paid by industry j for type l labor including payroll taxes

**  5.1.3 Nominal (value) variables
 CAB             Current account balance
 CTH(h)          Consumption budget of type h households
 G               Current government expenditures on goods and services
 GDP_BP          GDP at basic prices
 GDP_FD          GDP at purchasers' prices from the perspective of final demand
 GDP_IB          GDP at market prices (income-based)
 GDP_MP          GDP at market prices
 GFCF            Gross fixed capital formation
 IT              Total investment expenditures
 SF(f)           Savings of type f businesses
 SG              Government savings
 SH(h)           Savings of type h households
 SROW            Rest-of-the-world savings
 TDF(f)          Income taxes of type f businesses
 TDFT            Total government revenue from business income taxes
 TDH(h)          Income taxes of type h households
 TDHT            Total government revenue from household income taxes
 TIC(i)          Government revenue from indirect taxes on product i
 TICT            Total government receipts of indirect taxes on commodities
 TIK(k,j)        Government revenue from taxes on type k capital used by industry j
 TIKT            Total government revenue from from taxes on capital
 TIM(m)          Government revenue from import duties on product m
 TIMT            Total government revenue from import duties
 TIP(j)          Government revenue from taxes on industry j production (excluding taxes directly related to the use of capital and labor)
 TIPT            Total government revenue from production taxes (excluding taxes directly related to the use of capital and labor)
 TIW(l,j)        Government revenue from payroll taxes on type l labor in industry j
 TIWT            Total government revenue from payroll taxes
 TIX(x)          Government revenue from export taxes on product x
 TIXT            Total government revenue from export taxes
 TPRCTS          Total government revenue from taxes on products and imports
 TPRODN          Total government revenue from other taxes on production
 TR(ag,agj)      Transfers from agent agj to agent ag
 YDF(f)          Disposable income of type f businesses
 YDH(h)          Disposable income of type h households
 YF(f)           Total income of type f businesses
 YFK(f)          Capital income of type f businesses
 YFTR(f)         Transfer income of type f businesses
 YG              Total government income
 YGK             Government capital income
 YGTR            Government transfer income
 YH(h)           Total income of type h households
 YHK(h)          Capital income of type h households
 YHL(h)          Labor income of type h households
 YHTR(h)         Transfer income of type h households
 YROW            Rest-of-the-world income

**  5.1.4 Other variables
 LEON            Excess supply on the last market
;


** 5.2 Equation definition

EQUATIONS

 EQ1(j)          Value added demand in industry j (Leontief)
 EQ2(j)          Total intermediate consumption demand in industry j (Leontief)
 EQ3(j)          CES between of composite labor and capital
 EQ3b(j)         Value added equals labor for industries with no capital
 EQ4(j)          Relative demand for composite labor and capital by industry j(CES)
 EQ5(j)          CES between labor categories
 EQ6(l,j)        Demand for type l labor by industry j (CES)
 EQ7(j)          CES between capital categories
 EQ8(k,j)        Demand for type k capital by industry j (CES)
 EQ9(i,j)        Intermediate consumption of commodity i by industry j (Leontief)
 EQ10(h)         Total income of type h households
 EQ11(h)         Labor income of type h households
 EQ12(h)         Capital income of type h households
 EQ13(h)         Transfer income of type h households
 EQ14(h)         Disposable income of type h households
 EQ15(h)         Consumption budget of type h households
 EQ16(h)         Savings of type h households
 EQ17(f)         Total income of type f businesses
 EQ18(f)         Capital income of type f businesses
 EQ19(f)         Transfer income of type f businesses
 EQ20(f)         Disposable income of type f businesses
 EQ21(f)         Savings of type f businesses
 EQ22            Total government income
 EQ23            Government capital income
 EQ24            Total government revenue from household income taxes
 EQ25            Total government revenue from business income taxes
 EQ26            Total government revenue from other taxes on production
 EQ27            Total government receipts of indirect taxes on wages
 EQ28            Total government receipts of indirect taxes on capital
 EQ29            Total government revenue from production taxes
 EQ30            Total government revenue from taxes on products and imports
 EQ31            Total government receipts of indirect taxes on commodities
 EQ32            Total government revenue from import duties
 EQ33            Total government revenue from export taxes
 EQ34            Government transfer income
 EQ35(h)         Income taxes of type h households
 EQ36(f)         Income taxes of type f businesses
 EQ37(l,j)       Government revenue from payroll taxes on type l labor in industry j
 EQ38(k,j)       Government revenue from taxes on type k capital used by industry j
 EQ39(j)         Government revenue from taxes on industry j production
 EQ40(nm)        Government revenue from indirect taxes on product nm
 EQ41(m)         Government revenue from indirect taxes on product m
 EQ42(m)         Government revenue from import duties on product m
 EQ43(x)         Government revenue from export taxes on product x
 EQ44            Government savings
 EQ45            Rest-of-the-world income
 EQ46            Rest-of-the-world savings
 EQ47            Equivalence between current account balance and ROW savings
 EQ48(agng,h)    Transfers from household h to agent agng
 EQ49(h)         Transfers from household h to government
 EQ50(ag,f)      Transfers from type f businesses to agent ag
 EQ51(agng)      Public transfers
 EQ52(agd)       Transfers from abroad
 EQ53(i,h)       Consumption of commodity i by type h households
 EQ54            Gross fixed capital formation
 EQ55(i)         Final demand of commodity i for investment purposes (GFCF)
 EQ56(i)         Public final consumption of commodity i
 EQ57(i)         Total intermediate demand for commodity i
 EQ58(i)         Demand for commodity i as a trade or transport margin
 EQ59(j)         CET between different commodities produced by industry j
 EQ60(j,i)       Industry j production of commodity i (CET)
 EQ61(j,x)       CET between exports and local commodity
 EQ62(j,nx)      Equivalence between XS and DS for non exported commodities
 EQ63(j,x)       Relative supply of exports and local commodity (CET)
 EQ63a(j,x)      Equivalence between XS and DS for commodities only sold locally
 EQ63b(j,x)      Equivalence between XS and EX for commodities only exported
 EQ64(x)         World demand for exports of product x
 EQ65(m)         CES between imports and local production
 EQ66(nm)        Equivalence between Q and D for non importable
 EQ67(m)         Demand for imports (CES)
 EQ68(j)         Industry j unit cost
 EQ69(j)         Basic price of industry j's production of commodity i
 EQ70(j)         Intermediate consumption price index of industry j
 EQ71(j)         Price of industry j value added
* EQ72(j)         Wage rate of industry j composite labor
 EQ73(l,j)       Wage rate paid by industry j for type l labor including payroll taxes
* EQ74(j)         Rental rate of industry j composite capital
 EQ75(k,j)       Rental rate paid by industry j for type k capital including capital taxes
 EQ76(k,j)       Rental rate of type k capital (if capital is mobile)
 EQ77(j,i)       Total producer price is equal to P if there is only one product
 EQ78(j,x)       Basic price of industry j's production of commodity x
 EQ79(j,nx)      Equivalence between P and PL for non exportable
 EQ80(x)         Price received for exported commodity x (excluding export taxes)
 EQ81(i)         Price of local product i sold on the domestic market (including all taxes and margins)
 EQ82(m)         Price of imported product m (including all taxes and tariffs)
 EQ83(m)         Purchaser price of composite comodity m
 EQ84(nm)        Equivalence between PC and PD for non imported commodities
 EQ85            GDP deflator (Fischer index)
 EQ86            Consumer price index (Laspeyres)
 EQ87            Investment price index (derived from investment function)
 EQ88            Public expenditures price index
 EQ89(i1)        Domestic absorbtion
 EQ90(l)         Labor supply equals labor demand
 EQ91(k)         Capital supply equals capital demand
 EQ92            Total investment equals total savings
 EQ93            Supply of domestic production equals local demand
 EQ94(x)         Supply of exports equals international world demand
 EQ95            GDP at basic prices
 EQ96            GDP at market prices
 EQ97            GDP at market prices (income-based)
 EQ98            GDP at purchasers' prices from the perspective of final demand

 WALRAS          Walras law verification
;

** 5.3 Equations

**  5.3.1 Production

 EQ1(j)..        VA(j) =e= v(j)*XST(j);

 EQ2(j)..        CI(j) =e= io(j)*XST(j);

 EQ3(j)$KDCO(J)..
                 VA(j) =e= B_VA(j)*[beta_VA(j)*LDC(j)**(-rho_VA(j))+
                          (1-beta_VA(j))*KDC(j)**(-rho_VA(j))]**(-1/rho_VA(j));

 EQ3b(j)$(KDCO(J) EQ 0)..
                 VA(j) =e= LDC(j);

 EQ4(j)$KDCO(J)..
                 LDC(j) =e= {[beta_VA(j)/(1-beta_VA(j))]*[RC(j)/WC(j)]}
                           **sigma_VA(j)*KDC(j);

 EQ5(j)..        LDC(j) =e= B_LD(j)*SUM[l$LDO(l,j),beta_LD(l,j)*LD(l,j)
                            **(-rho_LD(j))]**(-1/rho_LD(j));

 EQ6(l,j)$LDO(l,j)..
                 LD(l,j) =e= [beta_LD(l,j)*WC(j)/WTI(l,j)]**sigma_LD(j)
                             *B_LD(j)**(sigma_LD(j)-1)*LDC(j);

 EQ7(j)$KDCO(j)..
                 KDC(j) =e= B_KD(j)*SUM[k$KDO(k,j),beta_KD(k,j)*KD(k,j)
                            **(-rho_KD(j))]**(-1/rho_KD(j));

 EQ8(k,j)$KDO(k,j)..
                 KD(k,j) =e= [beta_KD(k,j)*RC(j)/RTI(k,j)]**sigma_KD(j)
                             *B_KD(j)**(sigma_KD(j)-1)*KDC(j);


 EQ9(i,j)..      DI(i,j) =e= aij(i,j)*CI(j);

**  5.3.2 Income and savings
**    5.3.2.1 Households

 EQ10(h)..       YH(h) =e= YHL(h)+YHK(h)+YHTR(h);

 EQ11(h)..       YHL(h) =e= SUM[l,lambda_WL(h,l)*W(l)*SUM(j$LDO(l,j),LD(l,j))];

 EQ12(h)..       YHK(h) =e= SUM[k,lambda_RK(h,k)*SUM(j$KDO(k,j),R(k,j)*KD(k,j))];

 EQ13(h)..       YHTR(h) =e= SUM[ag,TR(h,ag)];

 EQ14(h)..       YDH(h) =e= YH(h)-TDH(h)-TR('gvt',h);

 EQ15(h)..       CTH(h) =e= YDH(h)-SH(h)-SUM[agng,TR(agng,h)];

 EQ16(h)..       SH(h) =e= PIXCON**eta*sh0(h)+sh1(h)*YDH(h);


**    5.3.2.2 Firms

 EQ17(f)..       YF(f) =e= YFK(f)+YFTR(f);

 EQ18(f)..       YFK(f) =e= SUM[k,lambda_RK(f,k)*SUM(j$KDO(k,j),R(k,j)*KD(k,j))];

 EQ19(f)..       YFTR(f) =e= SUM[ag,TR(f,ag)];

 EQ20(f)..       YDF(f) =e= YF(f)-TDF(f);

 EQ21(f)..       SF(f) =e= YDF(f)-SUM[ag,TR(ag,f)];

**    5.3.2.3 Government

 EQ22..          YG =e= YGK+TDHT+TDFT+TPRODN+TPRCTS+YGTR ;

 EQ23..          YGK =e= SUM[k,lambda_RK('gvt',k)*SUM(j$KDO(k,j),R(k,j)*KD(k,j))];

 EQ24..          TDHT =e= SUM[h,TDH(h)];

 EQ25..          TDFT =e= SUM[f,TDF(f)];

 EQ26..          TPRODN =e= TIWT+TIKT+TIPT;

 EQ27..          TIWT =e= SUM[(l,j)$LDO(l,j),TIW(l,j)];

 EQ28..          TIKT =e= SUM[(k,j)$KDO(k,j),TIK(k,j)];

 EQ29..          TIPT =e= SUM[j,TIP(j)];

 EQ30..          TPRCTS =e= TICT+TIMT+TIXT;

 EQ31..          TICT =e= SUM[i,TIC(i)];

 EQ32..          TIMT =e= SUM[m,TIM(m)];

 EQ33..          TIXT =e= SUM[x,TIX(x)];

 EQ34..          YGTR =e= SUM[agng,TR('gvt',agng)];

 EQ35(h)..       TDH(h) =e= PIXCON**eta*ttdh0(h)+ttdh1(h)*YH(h);

 EQ36(f)..       TDF(f) =e= PIXCON**eta*ttdf0(f)+ttdf1(f)*YFK(f);

 EQ37(l,j)$LDO(l,j)..
                 TIW(l,j) =e= ttiw(l,j)*W(l)*LD(l,j);

 EQ38(k,j)$KDO(k,j)..
                 TIK(k,j) =e= ttik(k,j)*R(k,j)*KD(k,j);

 EQ39(j)..       TIP(j) =e= ttip(j)*PP(j)*XST(j);

 EQ40(nm)..      TIC(nm) =e= ttic(nm)*(PL(nm)+SUM[i,PC(i)*tmrg(i,nm)])*DD(nm);

 EQ41(m)..       TIC(m) =e= ttic(m)*[(PL(m)+SUM[i,PC(i)*tmrg(i,m)])*DD(m)
                            +((1+ttim(m))*e*PWM(m)+SUM[i,PC(i)*tmrg(i,m)])*IM(m)];

 EQ42(m)..       TIM(m) =e= ttim(m)*e*PWM(m)*IM(m);

 EQ43(x)..       TIX(x) =e= ttix(x)*(PE(x)+SUM[i,PC(i)*tmrg_X(i,x)])*EXD(x);

 EQ44..          SG =e= YG-SUM[agng,TR(agng,'gvt')]-G;

**    5.3.2.4 Rest of the world

 EQ45..          YROW =e= e*SUM[m,PWM(m)*IM(m)]
                          +SUM[k,lambda_RK('row',k)*SUM(j$KDO(k,j),R(k,j)*KD(k,j))]
                          +SUM[agd,TR('row',agd)];

 EQ46..          SROW =e= YROW-SUM[x,PE_FOB(x)*EXD(x)]-SUM[agd,TR(agd,'row')];

 EQ47..          SROW =e= -CAB;

**    5.3.2.5 Transfers

 EQ48(agng,h)..  TR(agng,h) =e= lambda_TR(agng,h)*YDH(h);

 EQ49(h)..       TR('gvt',h) =e= PIXCON**eta*tr0(h)+tr1(h)*YH(h);

 EQ50(ag,f)..    TR(ag,f) =e= lambda_TR(ag,f)*YDF(f);

 EQ51(agng)..    TR(agng,'gvt') =e= PIXCON**eta*TRO(agng,'gvt');

 EQ52(agd)..     TR(agd,'row') =e= PIXCON**eta*TRO(agd,'row');


**  5.3.3 Demand

 EQ53(i,h)..     C(i,h)*PC(i) =e= CMIN(i,h)*PC(i)+gamma_LES(i,h)*(CTH(h)-
                                  SUM[ij,CMIN(ij,h)*PC(ij)]);

 EQ54..          GFCF =e= IT-SUM[i,PC(i)*VSTK(i)];

 EQ55(i)..       PC(i)*INV(i) =e= gamma_INV(i)*GFCF;

 EQ56(i)..       PC(i)*CG(i) =e= gamma_GVT(i)*G;

 EQ57(i)..       DIT(i) =e= SUM[j,DI(i,j)];

 EQ58(i)..       MRGN(i) =e= SUM[ij,tmrg(i,ij)*DD(ij)]
                            +SUM[m,tmrg(i,m)*IM(m)]
                            +SUM[x,tmrg_X(i,x)*EXD(x)];



**  5.3.4 International trade

 EQ59(j)..       XST(j) =e= B_XT(j)*SUM[i$XSO(j,i),beta_XT(j,i)*XS(j,i)
                            **rho_XT(j)]**(1/rho_XT(j));

 EQ60(j,i)$(XSO(j,i) and (XSO(j,i) ne XSTO(j)))..
                 XS(j,i) =e= XST(j)/B_XT(j)**(1+sigma_XT(j))*
                             {P(j,i)/[beta_XT(j,i)*PT(j)]}**sigma_XT(j);

 EQ61(j,x)$(EXO(j,x) and DSO(j,x))..
                 XS(j,x) =e= B_X(j,x)*[beta_X(j,x)*EX(j,x)**rho_X(j,x)
                           +(1-beta_X(j,x))*DS(j,x)**rho_X(j,x)]
                           **(1/rho_X(j,x));

 EQ62(j,nx)$XSO(j,nx)..
                 XS(j,nx) =e= DS(j,nx);

 EQ63(j,x)$(EXO(j,x) and DSO(j,x))..
                 EX(j,x) =e= {[(1-beta_X(j,x))/beta_X(j,x)]*[PE(x)/PL(x)]}
                           **sigma_X(j,x)*DS(j,x);

 EQ63a(j,x)$((EXO(j,x) eq 0) and DSO(j,x))..
                 XS(j,x) =e= DS(j,x);

 EQ63b(j,x)$(EXO(j,x) and (DSO(j,x) eq 0))..
                 XS(j,x) =e= EX(j,x);

 EQ64(x)..       EXD(x)  =e=  EXDO(x)*[e*PWX(x)/PE_fob(x)]**sigma_XD(x);

 EQ65(m)..       Q(m) =e= B_M(m)*[beta_M(m)*IM(m)**(-rho_M(M))+(1-beta_M(m))
                                  *DD(m)**(-rho_M(M))]**(-1/rho_M(M));

 EQ66(nm)..      Q(nm) =e= DD(nm);

 EQ67(m)..       IM(m) =e= {[beta_M(m)/(1-beta_M(m))]*[PD(m)/PM(m)]}
                           **sigma_M(m)*DD(m);

**  5.3.5 Prices

 EQ68(j)..       PP(j)*XST(j) =e= PVA(j)*VA(j)+PCI(j)*CI(j);

 EQ69(j)..       PT(j) =e= (1+ttip(j))*PP(j);

 EQ70(j)..       PCI(j)*CI(j) =e= SUM[i,PC(i)*DI(i,j)];

 EQ71(j)..       PVA(j)*VA(j) =e= WC(j)*LDC(j)+RC(j)*KDC(j)$KDCO(j);

* Given the way equation 6 is written, equation 72 is redundant
* EQ72(j)..       WC(j)*LDC(j) =e= SUM[l$LDO(l,j),WTI(l,j)*LD(l,j)];

 EQ73(l,j)..     WTI(l,j) =e= W(l)*(1+ttiw(l,j));

* Given the way equation 8 is written, equation 74 is redundant
* EQ74(j)$(kmob and KDCO(j))..
*                 RC(j)*KDC(j) =e= SUM[k$KDO(k,j),RTI(k,j)*KD(k,j)];

 EQ75(k,j)$KDO(k,j)..
                 RTI(k,j) =e= R(k,j)*(1+ttik(k,j));

 EQ76(k,j)$(kmob and KDO(k,j))..
                 R(k,j) =e= RK(k);

* Given the way equation 60 is written, equation 77 is redundant if
* a sector produces more than one commodity
* EQ77(j)..      PT(j)*XST(j) =e= SUM[i,P(j,i)*XS(j,i)];

 EQ77(j,i)$(XSO(j,i) eq XSTO(j))..
                 P(j,i) =e= PT(j);

 EQ78(j,x)$XSO(j,x)..
                 P(j,x)*XS(j,x) =e= PE(x)*EX(j,x)$EXO(j,x)
                                   +PL(x)*DS(j,x)$DSO(j,x);

 EQ79(j,nx)$XSO(j,nx)..
                 P(j,nx) =e= PL(nx);

 EQ80(x)..       (1+ttix(x))*(PE(x)+SUM[i,PC(i)*tmrg_X(i,x)]) =e= PE_FOB(x);

 EQ81(i)..       PD(i) =e= (1+ttic(i))*(PL(i)+SUM[ij,PC(ij)*tmrg(ij,i)]);

 EQ82(m)..       PM(m) =e= (1+ttic(m))*{(1+ttim(m))*
                           e*PWM(m)+SUM[i,PC(i)*tmrg(i,m)]};

 EQ83(m)..       PC(m)*Q(m) =e= PM(m)*IM(m)+PD(m)*DD(m);

 EQ84(nm)..      PC(nm) =e= PD(nm);

 EQ85..          PIXGDP =e= {SUM[j,PVA(j)*VAO(j)]/SUM[j,PVAO(j)*VAO(j)]*
                             SUM[j,PVA(j)*VA(j)]/SUM[j,PVAO(j)*VA(j)]}**0.5;

 EQ86..          PIXCON =e= SUM[i,PC(i)*SUM[h,CO(i,h)]]
                           /SUM[i,PCO(i)*SUM[h,CO(i,h)]];

 EQ87..          PIXINV =e= PROD[i$gamma_INV(i),(PC(i)/PCO(i))**gamma_INV(i)];

 EQ88..          PIXGVT =e= PROD[i$gamma_GVT(i),(PC(i)/PCO(i))**gamma_GVT(i)];

**  5.3.6 Equilibrim

 EQ89(i1)..      Q(i1) =e= SUM[h,C(i1,h)]+CG(i1)+INV(i1)+VSTK(i1)+DIT(i1)
                           +MRGN(i1);

 EQ90(l)..       LS(l) =e= SUM[j$LDO(l,j),LD(l,j)];

 EQ91(k)..       KS(k) =e= SUM[j$KDO(k,j),KD(k,j)];

 EQ92..          IT =e= SUM[h,SH(h)]+SUM[f,SF(f)]+SG+SROW;

 EQ93(i)..       SUM[j$DSO(j,i),DS(j,i)] =e= DD(i);

 EQ94(x)..       SUM[j$EXO(j,x),EX(j,x)] =e= EXD(x);


**  5.3.4 Gross domestic product

 EQ95..          GDP_BP =e= SUM[j,PVA(j)*VA(j)]+TIPT;

 EQ96..          GDP_MP =e= GDP_BP+TPRCTS;

 EQ97..          GDP_IB =e= SUM[(l,j)$LDO(l,j),W(l)*LD(l,j)]
                           +SUM[(k,j)$KDO(k,j),R(k,j)*KD(k,j)]
                           +TPRODN+TPRCTS;

 EQ98..          GDP_FD =e= SUM[i,PC(i)*(SUM[h,C(i,h)]+CG(i)+INV(i)+VSTK(i))]
                           +SUM[x,PE_FOB(x)*EXD(x)]-SUM[m,PWM(m)*e*IM(m)];

**  5.3.7 Other

 WALRAS..        LEON =e= Q('agr')-SUM[h,C('agr',h)]-CG('agr')-INV('agr')
                          -VSTK('agr')-DIT('agr')-MRGN('agr');


* 6 Numerical resolution

** 6.1 Variable initialisation
**  6.1.1 Volume variables
 C.l(i,h)        = CO(i,h);
 CG.l(i)         = CGO(i);
 CI.l(j)         = CIO(j);
 CMIN.l(i,h)     = CMINO(i,h);
 DD.l(i)         = DDO(i);
 DI.l(i,j)       = DIO(i,j);
 DIT.l(i)        = DITO(i);
 DS.l(j,i)       = DSO(j,i);
 EX.l(j,x)       = EXO(j,x);
 EXD.l(x)        = EXDO(x);
 IM.l(m)         = IMO(m);
 INV.l(i)        = INVO(i);
 KD.l(k,j)       = KDO(k,j);
 KDC.l(j)        = KDCO(j);
 KS.l(k)         = KSO(k);
 LD.l(l,j)       = LDO(l,j);
 LDC.l(j)        = LDCO(j);
 LS.l(l)         = LSO(l);
 MRGN.l(i)       = MRGNO(i);
 Q.l(i)          = QO(i);
 VA.l(j)         = VAO(j);
 VSTK.l(i)       = VSTKO(i);
 XS.l(j,i)       = XSO(j,i);
 XST.l(j)        = XSTO(j);

**  6.1.2 Price variables
 e.l             = eO;
 P.l(j,i)        = PO(j,i);
 PC.l(i)         = PCO(i);
 PCI.l(j)        = PCIO(j);
 PD.l(i)         = PDO(i);
 PE.l(x)         = PEO(x);
 PE_FOB.l(x)     = PE_FOBO(x);
 PIXCON.l        = PIXCONO;
 PIXGDP.l        = PIXGDPO;
 PIXGVT.l        = PIXGVTO;
 PIXINV.l        = PIXINVO;
 PL.l(i)         = PLO(i);
 PM.l(m)         = PMO(m);
 PP.l(j)         = PPO(j);
 PT.l(j)         = PTO(j);
 PVA.l(j)        = PVAO(j);
 PWM.l(m)        = PWMO(m);
 PWX.l(x)        = PWXO(x);
 R.l(k,j)        = RO(k,j);
 RC.l(j)         = RCO(j);
 RK.l(k)         = RKO(k);
 RTI.l(k,j)      = RTIO(k,j);
 W.l(l)          = WO(l);
 WC.l(j)         = WCO(j);
 WTI.l(l,j)      = WTIO(l,j);

**  6.1.3 Nominal (value) variables
 CAB.l           = CABO;
 CTH.l(h)        = CTHO(h);
 G.l             = GO;
 GDP_BP.l        = GDP_BPO;
 GDP_FD.l        = GDP_FDO;
 GDP_IB.l        = GDP_IBO;
 GDP_MP.l        = GDP_MPO;
 GFCF.l          = GFCFO;
 IT.l            = ITO;
 SF.l(f)         = SFO(f);
 SG.l            = SGO;
 SH.l(h)         = SHO(h);
 SROW.l          = SROWO;
 TDF.l(f)        = TDFO(f);
 TDFT.l          = TDFTO;
 TDH.l(h)        = TDHO(h);
 TDHT.l          = TDHTO;
 TIC.l(i)        = TICO(i);
 TICT.l          = TICTO;
 TIK.l(k,j)      = TIKO(k,j);
 TIKT.l          = TIKTO;
 TIM.l(m)        = TIMO(m);
 TIMT.l          = TIMTO;
 TIP.l(j)        = TIPO(j);
 TIPT.l          = TIPTO;
 TIW.l(l,j)      = TIWO(l,j);
 TIWT.l          = TIWTO;
 TIX.l(x)        = TIXO(x);
 TIXT.l          = TIXTO;
 TPRCTS.l        = TPRCTSO;
 TPRODN.l        = TPRODNO;
 TR.l(ag,agj)    = TRO(ag,agj);
 YDF.l(f)        = YDFO(f);
 YDH.l(h)        = YDHO(h);
 YF.l(f)         = YFO(f);
 YFK.l(f)        = YFKO(f);
 YFTR.l(f)       = YFTRO(f);
 YG.l            = YGO;
 YGK.l           = YGKO;
 YGTR.l          = YGTRO;
 YH.l(h)         = YHO(h);
 YHK.l(h)        = YHKO(h);
 YHL.l(h)        = YHLO(h);
 YHTR.l(h)       = YHTRO(h);
 YROW.l          = YROWO;

**  6.1.4  Other
 LEON.l          = 0;
;


** 6.2 Choice of mobile or sector-specific capital

*  If kmob=1, capital is mobile, if kmob=0, it is sector-specific
 kmob            = 0;
 KD.fx(k,j)$(kmob eq 0)
                 = KDO(k,j);
 KS.fx(k)$kmob   = KSO(k);

** 6.3 Closures
*  The numeraire is the nominal exchange rate

 e.fx            = 1;

 CAB.fx          = CABO;
 CMIN.fx(i,h)    = CMINO(i,h);
 G.fx            = GO;
 LS.fx(l)        = LSO(l);
 PWM.fx(m)       = PWMO(m);
 PWX.fx(x)       = PWXO(x);
 VSTK.fx(i)      = VSTKO(i);


** 6.4 Resolution

OPTION NLP = conopt3
MODEL PEP11 Standard PEP static model  /ALL/;
PEP11.HOLDFIXED=1;
SOLVE PEP11 USING CNS;


